# tropicpy

Welcome to **tropicpy** repository! Here you can find implementation of tropical cryptographic protocols and attacks. 

Currently available are protocols:
1. Grigorie-Shpilrain (2014)
2. Grigorie-Shpilrain (2019)

and attacks:
1. Kotov-Ushakov simple and general attacks on Grigorie-Shpilrain (2014) protocol
2. Rudy-Monico attack on Grigorie-Shpilrain (2019) protocol
3. Isaac-Kahrobaei attack on Grigorie-Shpilrain (2019) protocol.

## How to use?
If you wish to use protocols and attacks implemented in tropicpy you can install tropicpy package using

    pip install tropicpy
To see examples of tropical operarations and cryptosystems run

    tropicpy_demo()